@@ -1,4 +1,5 @@
 use chrono::Utc;
+
 use parking_lot::Mutex;
 use std::sync::Arc;
 
@@ -10,6 +11,7 @@ pub struct Snowflake {
     last_timestamp: Arc<Mutex<i64>>,
 }
 
+#[derive(Debug, PartialEq, Eq)]
 pub struct SnowflakeData {
     pub timestamp: i64,
     pub worker_id: i32,
@@ -20,10 +22,20 @@ pub struct SnowflakeData {
 impl Snowflake {
     /// Generates Snowflake instance, using the defaults. These could be overriden by calling the
     /// relevant set_* functions.
-    pub fn new() -> Snowflake {
+    pub fn new(epoch: i64, worker_id: i32, node_id: i32) -> Snowflake {
+        Snowflake {
+            epoch,
+            worker_id,
+            node_id,
+            sequence: 0,
+            last_timestamp: Arc::new(Mutex::new(0)),
+        }
+    }
+
+    pub fn default() -> Snowflake {
         Snowflake {
             epoch: 0,
-            worker_id: 1,
+            worker_id: 0,
             node_id: 1,
             sequence: 0,
             last_timestamp: Arc::new(Mutex::new(0)),
@@ -47,7 +59,7 @@ impl Snowflake {
         self.node_id = node_id;
         self
     }
-    /// Generates u64 snowflake based on current unix timestamp. retrieves other information based
+    /// Generates i64 snowflake based on current unix timestamp. retrieves other information based
     /// on Snowflake's configurations.
     pub fn generate(&mut self) -> i64 {
         let mut last_timestamp = self.last_timestamp.lock();
@@ -70,21 +82,21 @@ impl Snowflake {
             node_id: self.node_id,
             sequence: self.sequence,
         };
-        Snowflake::assemble(data)
+        self.assemble(data)
     }
 
-    /// Assembles SnowflakeData to u64 snowflake.
+    /// Assembles SnowflakeData to i64 snowflake.
     /// This function only performs Bitwise operations & expects the user to handle collisions, etc
     /// In most cases, you probably don't want to use this.
-    pub fn assemble(data: SnowflakeData) -> i64 {
+    pub fn assemble(&self, data: SnowflakeData) -> i64 {
         (data.timestamp << 22)
             | ((data.worker_id << 17) as i64)
             | ((data.node_id << 12) as i64)
             | (data.sequence as i64)
     }
 
-    /// Disassembles u64 snowflake to SnowflakeData.
-    pub fn disassemble(&self, id: &i64) -> SnowflakeData {
+    /// Disassembles i64 snowflake to SnowflakeData.
+    pub fn disassemble(&self, id: i64) -> SnowflakeData {
         SnowflakeData {
             timestamp: ((id >> 22) + self.epoch),
             worker_id: ((id & 0x003E_0000) >> 17) as i32,
